#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MAXINIT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MAXINIT_HPP_INCLUDED

#include <boost/simd/constant/include/constants/maxinit.hpp>

#endif
